import { ScalarsMap, NamingConvention, ConvertFn, ConvertOptions } from './types';
import { DeclarationBlockConfig } from './utils';
import { GraphQLSchema, FragmentDefinitionNode, OperationDefinitionNode, ASTNode } from 'graphql';
import { SelectionSetToObject } from './selection-set-to-object';
import { OperationVariablesToObject } from './variables-to-object';
import { BaseVisitorConvertOptions } from './base-visitor';
export interface ParsedDocumentsConfig {
    scalars: ScalarsMap;
    convert: ConvertFn<ConvertOptions>;
    typesPrefix: string;
    addTypename: boolean;
}
export interface RawDocumentsConfig {
    scalars?: ScalarsMap;
    namingConvention?: NamingConvention;
    typesPrefix?: string;
    skipTypename?: boolean;
}
export declare class BaseDocumentsVisitor<TRawConfig extends RawDocumentsConfig = RawDocumentsConfig, TPluginConfig extends ParsedDocumentsConfig = ParsedDocumentsConfig> {
    protected _schema: GraphQLSchema;
    protected _parsedConfig: TPluginConfig;
    protected _declarationBlockConfig: DeclarationBlockConfig;
    protected _unnamedCounter: number;
    protected _variablesTransfomer: OperationVariablesToObject;
    protected _selectionSetToObject: SelectionSetToObject;
    constructor(rawConfig: TRawConfig, additionalConfig: TPluginConfig, _schema: GraphQLSchema, defaultScalars?: ScalarsMap);
    setSelectionSetHandler(handler: SelectionSetToObject): void;
    setDeclarationBlockConfig(config: DeclarationBlockConfig): void;
    setVariablesTransformer(variablesTransfomer: OperationVariablesToObject): void;
    convertName(node: ASTNode | string, options?: ConvertOptions & BaseVisitorConvertOptions): string;
    readonly config: TPluginConfig;
    readonly schema: GraphQLSchema;
    readonly scalars: ScalarsMap;
    readonly addTypename: boolean;
    private handleAnonymouseOperation;
    FragmentDefinition(node: FragmentDefinitionNode): string;
    OperationDefinition(node: OperationDefinitionNode): string;
}
